@@ -285,7 +285,7 @@ class DataCenter(object):
         
         Uploads a public key to be added to the account's credentials.
         """
-        data = json.dumps({'name': str(key_id), 'key': str(key)})
+        data = {'name': str(key_id), 'key': str(key)}
         j, _ = self.request('POST', 'keys', data=data)
         return j
     
@@ -700,6 +700,9 @@ class DataCenter(object):
             with open(boot_script) as f:
                 params['metadata.user-script'] = f.read()
         j, r = self.request('POST', 'machines', data=params)
+        if r.status_code >= 400:
+            print >> sys.stderr, j
+            r.raise_for_status()
         return Machine(datacenter=self, data=j)
     
     def machine(self, machine_id, credentials=False):
